==> istio-model-1.0.0-sources.jar: me/snowdrop/istio/mixer/adapter/memquota/Override.java <==

package me.snowdrop.istio.mixer.adapter.memquota;

import java.io.Serializable;
import java.util.Map;
import javax.validation.Valid;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "dimensions",
    "maxAmount",
    "validDuration"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, validationEnabled = true, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class Override implements Serializable
{

    /**
     * 
     * 
     */
    @JsonProperty("dimensions")
    @JsonPropertyDescription("")
    @Valid
    private Map<String, String> dimensions;
    /**
     * 
     * 
     */
    @JsonProperty("maxAmount")
    @JsonPropertyDescription("")
    private Long maxAmount;
    /**
     * 
     * 
     */
    @JsonProperty("validDuration")
    @JsonPropertyDescription("")
    private Long validDuration;
    private final static long serialVersionUID = -521481761481356224L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public Override() {
    }

    /**
     * 
     * @param validDuration
     * @param maxAmount
     * @param dimensions
     */
    public Override(Map<String, String> dimensions, Long maxAmount, Long validDuration) {
        super();
        this.dimensions = dimensions;
        this.maxAmount = maxAmount;
        this.validDuration = validDuration;
    }

    /**
     * 
     * 
     */
    @JsonProperty("dimensions")
    public Map<String, String> getDimensions() {
        return dimensions;
    }

    /**
     * 
     * 
     */
    @JsonProperty("dimensions")
    public void setDimensions(Map<String, String> dimensions) {
        this.dimensions = dimensions;
    }

    /**
     * 
     * 
     */
    @JsonProperty("maxAmount")
    public Long getMaxAmount() {
        return maxAmount;
    }

    /**
     * 
     * 
     */
    @JsonProperty("maxAmount")
    public void setMaxAmount(Long maxAmount) {
        this.maxAmount = maxAmount;
    }

    /**
     * 
     * 
     */
    @JsonProperty("validDuration")
    public Long getValidDuration() {
        return validDuration;
    }

    /**
     * 
     * 
     */
    @JsonProperty("validDuration")
    public void setValidDuration(Long validDuration) {
        this.validDuration = validDuration;
    }

}

==> istio-model-1.1.1-sources.jar: me/snowdrop/istio/mixer/adapter/memquota/Override.java <==

package me.snowdrop.istio.mixer.adapter.memquota;

import java.io.Serializable;
import java.util.Map;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyDescription;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.sundr.builder.annotations.Buildable;
import io.sundr.builder.annotations.BuildableReference;
import io.sundr.builder.annotations.Inline;
import lombok.EqualsAndHashCode;
import lombok.ToString;


/**
 * 
 * 
 */
@JsonInclude(JsonInclude.Include.NON_EMPTY)
@JsonPropertyOrder({
    "apiVersion",
    "kind",
    "metadata",
    "dimensions",
    "maxAmount",
    "validDuration"
})
@ToString
@EqualsAndHashCode
@Buildable(editableEnabled = false, generateBuilderPackage = true, builderPackage = "io.fabric8.kubernetes.api.builder", inline = {
    @Inline(type = Doneable.class, prefix = "Doneable", value = "done")
}, refs = {
    @BuildableReference(ObjectMeta.class)
})
public class Override implements Serializable
{

    /**
     * 
     * 
     */
    @JsonProperty("dimensions")
    @JsonPropertyDescription("")
    private Map<String, String> dimensions;
    /**
     * 
     * 
     */
    @JsonProperty("maxAmount")
    @JsonPropertyDescription("")
    private Integer maxAmount;
    /**
     * 
     * 
     */
    @JsonProperty("validDuration")
    @JsonPropertyDescription("")
    private Integer validDuration;
    private final static long serialVersionUID = -7318312159559492664L;

    /**
     * No args constructor for use in serialization
     * 
     */
    public Override() {
    }

    /**
     * 
     * @param validDuration
     * @param maxAmount
     * @param dimensions
     */
    public Override(Map<String, String> dimensions, Integer maxAmount, Integer validDuration) {
        super();
        this.dimensions = dimensions;
        this.maxAmount = maxAmount;
        this.validDuration = validDuration;
    }

    /**
     * 
     * 
     */
    @JsonProperty("dimensions")
    public Map<String, String> getDimensions() {
        return dimensions;
    }

    /**
     * 
     * 
     */
    @JsonProperty("dimensions")
    public void setDimensions(Map<String, String> dimensions) {
        this.dimensions = dimensions;
    }

    /**
     * 
     * 
     */
    @JsonProperty("maxAmount")
    public Integer getMaxAmount() {
        return maxAmount;
    }

    /**
     * 
     * 
     */
    @JsonProperty("maxAmount")
    public void setMaxAmount(Integer maxAmount) {
        this.maxAmount = maxAmount;
    }

    /**
     * 
     * 
     */
    @JsonProperty("validDuration")
    public Integer getValidDuration() {
        return validDuration;
    }

    /**
     * 
     * 
     */
    @JsonProperty("validDuration")
    public void setValidDuration(Integer validDuration) {
        this.validDuration = validDuration;
    }

}
